Core Components
===============

.. currentmodule:: biomol.core

Feature
-------


.. autosummary::
    :toctree: ./generated
    :nosignatures:

    Feature
    NodeFeature
    EdgeFeature


Container
---------

.. autosummary::
    :toctree: ./generated
    :nosignatures:

    FeatureContainer


IndexTable
----------

.. autosummary::
    :toctree: ./generated
    :nosignatures:

    IndexTable


View
----

.. autosummary::
    :toctree: ./generated
    :nosignatures:

    View
